Event Model
===========================

|code_ci| |docs_ci| |coverage| |pypi_version| |license|

============== ==============================================================
PyPI           ``pip install event-model``
Source code    https://github.com/bluesky/event-model
Documentation  https://blueskyproject.io/event-model
Releases       https://github.com/bluesky/event-model/releases
============== ==============================================================

.. |code_ci| image:: https://github.com/bluesky/event-model/actions/workflows/code.yml/badge.svg?branch=main
    :target: https://github.com/bluesky/event-model/actions/workflows/code.yml
    :alt: Code CI

.. |docs_ci| image:: https://github.com/bluesky/event-model/actions/workflows/docs.yml/badge.svg?branch=main
    :target: https://github.com/bluesky/event-model/actions/workflows/docs.yml
    :alt: Docs CI

.. |coverage| image:: https://codecov.io/gh/bluesky/event-model/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/bluesky/event-model
    :alt: Test Coverage

.. |pypi_version| image:: https://img.shields.io/pypi/v/event-model.svg
    :target: https://pypi.org/project/event-model
    :alt: Latest PyPI version

.. |license| image:: https://img.shields.io/badge/License-BSD-blue.svg
    :target: https://opensource.org/license/bsd-3-clause/
    :alt: BSD License

..
    Anything below this line is used when viewing README.rst and will be replaced
    when included in index.rst

See https://blueskyproject.io/event-model for more detailed documentation.
